@@ -21,11 +21,14 @@ from robot.libraries.BuiltIn import BuiltIn
 from robot.libraries.Collections import Collections
 from robot.utils.asserts import assert_true
 from robot.utils.robottime import secs_to_timestr
-from robot.utils.robottypes import *
+from robot.utils.robottypes import is_list_like, is_truthy
 from selenium import webdriver
 from selenium.common.exceptions import StaleElementReferenceException, TimeoutException
 
 
+JS_DOM_LOADED = "return document.readyState=='complete'"
+
+
 class Error(RuntimeError):
     ROBOT_CONTINUE_ON_FAILURE = True
 
@@ -162,8 +165,7 @@ class FacileToolkit2:
     def checkpoint(self, locator, timeout=None, error=None):
         self.set_selenium_library()
         self._wait_until(
-            lambda: self.sl.find_element(locator).is_displayed() and self.sl.execute_javascript(
-                "return document.readyState=='complete'"),
+            lambda: self.sl.find_element(locator).is_displayed() and self.sl.execute_javascript(JS_DOM_LOADED),
             "Element '%s' or their parents did not contain class in <TIMEOUT>." % locator, timeout, error
         )
 
@@ -208,7 +210,7 @@ class FacileToolkit2:
                 self.select_from_list_random_index(locator=locator, start_index=start_index, end_index=end_index, timeout=timeout) 
 
     @keyword
-    def i_land_on_page(self, url, timeout="60s"):
+    def i_land_on_page(self, url, timeout="60s", error=None):
         """
         Waits for a maximum time, defined by timeout argument (default=60s),
         until the location contains a portion of the url (specified by the parameter 'url')
@@ -216,8 +218,15 @@ class FacileToolkit2:
         self.set_selenium_library()
         try:
             self.sl.log_location()
-            self.sl.wait_until_location_contains(url, timeout)
-            self.dom_is_loaded(timeout=timeout)
+            self._wait_until(
+                lambda: url in self.sl.get_location() and self.sl.execute_javascript(JS_DOM_LOADED),
+                "Page %s didn't load correctly in <TIMEOUT>." % url,
+                timeout, error
+            )
+            is_jquery_present = BuiltIn().run_keyword_and_return_status('wait_for_condition', 'if(typeof(jQuery) == "function") {return true;} return false;', "1s")
+            if is_jquery_present:
+                self.wait_ajax_optional()
+
         except TimeoutException as e:
             if "renderer" in str(e.msg).lower():
                 self.sl.driver.refresh()
@@ -340,7 +349,7 @@ class FacileToolkit2:
         """
 
         if is_list_like(in_list):
-            if list:
+            if in_list:
                 return random.choice(*in_list)
             else:
                 raise AssertionError("List is empty")
@@ -426,14 +435,8 @@ class FacileToolkit2:
             self.wait_ajax(timeout)
             if BuiltIn().run_keyword_and_return_status("checkbox_should_not_be_selected", locator):
                 self.click_js(locator)
-        self.wait_ajax(timeout)
-        self.should_be_checked(*locators)
-
-    @keyword
-    def select_checkboxes(self, *locators):
-        for locator in locators:
-            if BuiltIn().run_keyword_and_return_status("checkbox_should_not_be_selected", locator):
-                self.click_js(locator)
+        if timeout is not None:
+            self.wait_ajax(timeout)
         self.should_be_checked(*locators)
 
     @keyword
@@ -497,7 +500,7 @@ class FacileToolkit2:
     def get_browser_options(browser, headless=False):
         if browser.lower() == "chrome":
             return FacileToolkit2.get_chrome_options(headless=headless)
-        elif browser == "firefox" or "ff":
+        elif browser == "firefox" or browser == "ff":
             return FacileToolkit2.get_ff_options(headless=headless)
         else:
             raise RobotError("{} unexpected browser name.".format(browser))
@@ -514,6 +517,7 @@ class FacileToolkit2:
         chrome_options.add_argument("--no-sandbox")
         chrome_options.add_argument("--disable-gpu")
         chrome_options.add_argument("--disable-browser-side-navigation")
+        chrome_options.add_argument("----dns-prefetch-disable")
         chrome_options.add_experimental_option("excludeSwitches", ["enable-automation"])
         chrome_options.set_capability("pageLoadStrategy", "eager")
         if headless:
@@ -550,6 +554,7 @@ class FacileToolkit2:
         chrome_options.add_argument("--no-sandbox")
         chrome_options.add_argument("--disable-gpu")
         chrome_options.add_argument("--disable-browser-side-navigation")
+        chrome_options.add_argument("----dns-prefetch-disable")
         chrome_options.add_experimental_option("excludeSwitches", ["enable-automation"])
         chrome_options.set_capability("pageLoadStrategy", "eager")
         if headless:
@@ -618,8 +623,8 @@ class FacileToolkit2:
     @keyword
     def click_label_from_field_locator(self, locator):
         self.set_selenium_library()
-        id = self.sl.get_element_attribute(locator, "id")
-        self.click_js("css: label[for='%s']" % id)
+        element_id = self.sl.get_element_attribute(locator, "id")
+        self.click_js("css: label[for='%s']" % element_id)
 
     @keyword
     def scroll_to_bottom(self):
@@ -629,7 +634,7 @@ class FacileToolkit2:
     def wait_for_condition_extended(self, *condition, timeout=None, error=None):
         self.set_selenium_library()
         jk = JavaScriptKeywords(self.sl)
-        js_code, js_args = jk._get_javascript_to_execute(condition)
+        js_code, _ = jk._get_javascript_to_execute(condition)
         if 'return' not in js_code:
             raise ValueError("Condition '%s' did not have mandatory 'return'." % js_code)
         self._wait_until(
@@ -650,7 +655,7 @@ class FacileToolkit2:
                                                                           "return Array.from(document.querySelectorAll('select, input')).map(p=>{return {id: p.id, value:p.value, text:p.text}})")
             if status == 'PASS' and return_value is not None:
                 Collections().log_list(list(return_value))
-        except:
+        except Exception:
             pass
 
     @keyword
@@ -690,8 +695,12 @@ class FacileToolkit2:
 
     @keyword
     def blur_jquery(self, locator):
-        for i in range(2):
+        try:
             self.execute_jquery_method_on_webelement(locator, "blur();")
+            BuiltIn().sleep("200ms")
+            self.execute_jquery_method_on_webelement(locator, "blur();")
+        except Exception:
+            pass
 
     @keyword
     def val_jquery(self, locator, value):
@@ -711,15 +720,11 @@ class FacileToolkit2:
         except:
             if mandatory:
                 raise
-            else:
-                pass
         try:
             self.click_js('id:onetrust-accept-btn-handler')
         except:
             if mandatory:
                 raise
-            else:
-                pass
 
     def _wait_until(self, condition, error, timeout=None, custom_error=None):
         self.set_selenium_library()
@@ -754,4 +759,4 @@ class FacileToolkit2:
 
 
 if __name__ == "__main__":
-    robot.run('../atests/keyword_tests.robot')
+    robot.run('%s/atests/keyword_tests.robot' % os.getcwd())
